==> nextcloud-app-news-1:27.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/sv.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "Nyhetsflöden",
    "Unread articles" : "Olästa artiklar",
    "News" : "Nyheter",
    "News folders" : "Nyhetsmappar",
    "News articles" : "Nyhetsartiklar",
    "Shared with me" : "Delad med mig",
    "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
    "Download" : "Hämta",
    "Close" : "Stäng",
    "Internal server error!" : "Internt serverfel!",
    "Unknown error!" : "Okänt fel!",
    "Web address" : "Webbadress",
    "Please check your data/nextcloud.log file for additional information!" : "Kontrollera din data/nextcloud.log-fil för ytterligare information!",
    "No folder" : "Ingen mapp",
    "Folder name" : "Mappnamn",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Feed exists already!" : "Flödet finns redan!",
    "New folder" : "Ny mapp",
    "Folder exists already!" : "Katalogen finns redan",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundläggande HTTP-autentiseringsuppgifter måste lagras okrypterade! Alla med åtkomst till servern eller databasen kommer att kunna få åtkomst till dem!",
    "Credentials" : "Inloggningsuppgifter",
    "Auto discover Feed" : "Upptäck flöde automatiskt",
    "Subscribe" : "Prenumerera",
    "Successfully updated news configuration" : "Nyhetskonfigurationen har uppdaterats",
    "Unable to update news config" : "Kunde inte uppdatera nyhetskonfigurationen",
    "No job execution data available. The cron job may not be running properly." : "Ingen data om jobbexekvering tillgänglig. Cron-jobbet kanske inte körs korrekt.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Senaste jobbexekveringen kördes {relativeTime}. Något är fel.",
    "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
    "Maximum read count per feed" : "Maximalt läsantal per flöde",
    "Maximum redirects" : "Maximala omdirigeringar",
    "Feed fetcher timeout" : "Timeout för flödes-hämtare",
    "Explore Service URL" : "Utforska tjänstwebbadress",
    "Update interval" : "Uppdateringsintervall",
    "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
    "Disable this if you use a custom updater." : "Slå av detta om du anväder en egen uppdateringsprocess.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definierar den maximala mängden artiklar som kan läsas per flöde som inte kommer att raderas av rensningsjobbet; om gamla artiklar dyker upp igen efter att ha lästs, öka detta värde; negativa värden som -1 kommer att stänga av denna funktion.",
    "Delete unread articles automatically" : "Radera olästa artiklar automatiskt",
    "Enable this if you also want to delete unread articles." : "Aktivera detta om du också vill ta bort olästa artiklar.",
    "How many redirects the feed fetcher should follow." : "Hur många omdirigeringar flödet skall tillåtas följa.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximalt antal sekunder att vänta på att RSS/Atom-flödet läses in; om det tar längre tid avbryts uppdateringen.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Om det anges kommer URL:en för denna tjänst att användas för att visa flöden i avsnittet utforska flöden. Lämna detta fält tomt för att använda den inbyggda utforskningsfunktionen.",
    "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
    "Use next update time for feed updates" : "Använd nästa uppdateringstid för flödesuppdateringar",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Aktivera detta för att använda den beräknade nästa uppdateringstiden för flödesuppdateringar. Inaktivera för att uppdatera flöden baserat enbart på uppdateringsintervallet.",
    "Article list" : "Artikellista",
    "Article details" : "Artikeldetaljer",
    "No article selected" : "Ingen artikel har valts",
    "Please select an article from the list." : "Välj en artikel från listan.",
    "Show all articles" : "Visa alla artiklar",
    "Move feed" : "Flytta flöde",
    "Please select the new folder" : "Välj den nya mappen",
    "Move" : "Flytta",
    "User Name" : "Användarnamn",
    "Share" : "Dela",
    "Share with" : "Dela med",
    "Share with {num} users" : "Dela med {num} användare",
    "Default" : "Förvald",
    "Compact" : "Kompakt",
    "Screenreader" : "Skärmläsare",
    "Vertical" : "Vertikal",
    "Horizontal" : "Horisontell",
    "Off" : "Av",
    "Please select a valid OPML file" : "Välj en giltig OPML-fil",
    "File successfully uploaded" : "Filen har laddats upp",
    "Error uploading the opml file" : "Fel vid uppladdning av opml-filen",
    "Error connecting to the server" : "Fel vid anslutning till servern",
    "Error retrieving the opml file" : "Det gick inte att hämta opml-filen",
    "Rename Folder" : "Byt namn på mapp",
    "Are you sure you want to delete?" : "Är du säker på att du vill ta bort?",
    "Mark read" : "Markera som läst",
    "All articles" : "Alla artiklar",
    "Recently viewed" : "Senast visade",
    "Starred" : "Stjärnmärkt",
    "Has feeds with errors!" : "Har flöden med fel!",
    "Explore" : "Utforska",
    "Settings" : "Inställningar",
    "Documentation" : "Dokumentation",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Article feed information" : "Artikelflödesinformation",
    "Display mode" : "Visningsläge",
    "Split mode" : "Delat läge",
    "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
    "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
    "Disable automatic refresh" : "Inaktivera automatisk uppdatering",
    "Abonnements (OPML)" : "Prenumerationer (OPML)",
    "Rename" : "Byt namn",
    "Delete" : "Ta bort",
    "Rename Feed" : "Döp om Feed",
    "Open Feed URL" : "Öppna flödes-URL",
    "Unpin from top" : "Ta bort från toppen",
    "Pin to top" : "Fäst i toppen",
    "Newest first" : "Nyaste först",
    "Oldest first" : "Äldst först",
    "Default order" : "Standardordning",
    "Enable full text" : "Aktivera fulltext",
    "Disable full text" : "Avaktivera fulltext",
    "Mark as unread on update" : "Markera som oläst vid uppdatering",
    "Keep read status on update" : "Behåll lässtatus vid uppdatering",
    "Sync disabled" : "Synk inaktiverad",
    "Sync enabled" : "Synk aktiverad",
    "Previous Item" : "Föregående objekt",
    "Next Item" : "Nästa objekt",
    "Share within Instance" : "Dela inom instans",
    "Toggle star article" : "Växla stjärnmärkning av artiklar",
    "Mark unread" : "Markera som oläst",
    "Close details" : "Stäng detaljer",
    "shared by" : "delad av",
    "by" : "av",
    "Play audio" : "Spela ljud",
    "Download audio" : "Hämta ljud",
    "Download video" : "Hämta video",
    "Refresh list" : "Uppdatera listan",
    "Open website" : "Öppna webbplats",
    "Keep article unread" : "Behåll artikel oläst",
    "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
    "Remove keep article unread" : "Ta bort behåll artikel oläst",
    "Importing feeds" : "Importerar flöden",
    "Please wait" : "Vänligen vänta",
    "Last update" : "Senaste uppdatering",
    "Time when the feed was last downloaded" : "Tidpunkt då flödet senast laddades ned",
    "Next update" : "Nästa uppdatering",
    "Time when the next feed update will be done" : "Tidpunkt då nästa flödesuppdatering kommer att göras",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Endast om det är aktiverat i admininställningarna, annars används det vanliga uppdateringsintervallet",
    "Articles per update" : "Artiklar per uppdatering",
    "Maximum number of articles reached in a feed update" : "Maximalt antal artiklar nådda i en flödesuppdatering",
    "Error Count" : "Antal fel",
    "Number of errors that have occurred since the last successful feed update" : "Antal fel som har inträffat sedan den senaste framgångsrika flödesuppdateringen",
    "Title" : "Titel",
    "Folder" : "Mapp",
    "Not available" : "Inte tillgänglig",
    "Keyboard shortcut" : "Tangentbordsgenvägar",
    "Action" : "Ågärd",
    "Jump to next article" : "Hoppa till nästa artikel",
    "(screenreader mode)" : "(skärmläsarläge)",
    "Jump to previous article" : "Hoppa till föregående artikel",
    "right" : "Höger",
    "left" : "vänster",
    "Star article and jump to next one" : "Stärnmärk artikel och hoppa till nästa",
    "Open article in new tab" : "Öppna artikeln i ny flik",
    "Show article details in compact view" : "Visa artikeldetaljer i kompakt vy",
    "Close article details in compact view" : "Stäng artikeldetaljer i kompakt vy",
    "Refresh" : "Uppdatera",
    "Load next feed" : "Läs in nästkommande flöde",
    "Load previous feed" : "Läs in föregående flöde",
    "Load previous folder" : "Läs in föregående mapp",
    "Load next folder" : "Läs in nästkommande mapp",
    "Scroll to active navigation entry" : "Skrolla till aktiv navigations-post",
    "Shift" : "Shift",
    "Mark current articles feed/folder as read" : "Markera aktuellt artikelflöde/mapp som läst",
    "All Articles" : "Alla artiklar",
    "No feeds found to add" : "Inga flöden hittades att lägga till",
    "Subscribe to" : "Prenumerera på",
    "Unread Articles" : "Olästa artiklar",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax- eller webcron-läge upptäckt! Dina flöden kommer inte uppdateras!",
    "How to set up the operating system cron" : "Hur man ställer in cron från operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installera och konfigurera en snabbare parallell uppdaterare som använder programmet Nyheter uppdatering API"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-1:28.0.0rc.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/sv.js <==
OC.L10N.register(
    "news",
    {
    "News" : "Nyheter",
    "Someone" : "Någon",
    "%1$s shared \"%2$s\" with you" : "%1$s delade \"%2$s\" med dig",
    "News feeds" : "Nyhetsflöden",
    "Unread articles" : "Olästa artiklar",
    "News folders" : "Nyhetsmappar",
    "News articles" : "Nyhetsartiklar",
    "Shared with me" : "Delad med mig",
    "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
    "Download" : "Hämta",
    "Close" : "Stäng",
    "Internal server error!" : "Internt serverfel!",
    "Unknown error!" : "Okänt fel!",
    "Web address" : "Webbadress",
    "Please check your data/nextcloud.log file for additional information!" : "Kontrollera din data/nextcloud.log-fil för ytterligare information!",
    "No folder" : "Ingen mapp",
    "Folder name" : "Mappnamn",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Feed exists already!" : "Flödet finns redan!",
    "New folder" : "Ny mapp",
    "Folder exists already!" : "Katalogen finns redan",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundläggande HTTP-autentiseringsuppgifter måste lagras okrypterade! Alla med åtkomst till servern eller databasen kommer att kunna få åtkomst till dem!",
    "Credentials" : "Inloggningsuppgifter",
    "Auto discover Feed" : "Upptäck flöde automatiskt",
    "Subscribe" : "Prenumerera",
    "Successfully updated news configuration" : "Nyhetskonfigurationen har uppdaterats",
    "Unable to update news config" : "Kunde inte uppdatera nyhetskonfigurationen",
    "Logo purge has never been run." : "Rensning av logotyper har aldrig körts.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Senaste rensningen av logotyper kördes {relativeLastLogoPurge}. Något är fel.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Senaste rensningen av logotyper kördes {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Ingen data om jobbexekvering tillgänglig. Cron-jobbet kanske inte körs korrekt.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Senaste jobbexekveringen kördes {relativeTime}. Något är fel.",
    "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
    "Maximum read count per feed" : "Maximalt läsantal per flöde",
    "Maximum redirects" : "Maximala omdirigeringar",
    "Feed fetcher timeout" : "Timeout för flödes-hämtare",
    "Explore Service URL" : "Utforska tjänstwebbadress",
    "Update interval" : "Uppdateringsintervall",
    "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
    "Disable this if you use a custom updater." : "Slå av detta om du anväder en egen uppdateringsprocess.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definierar den maximala mängden artiklar som kan läsas per flöde som inte kommer att raderas av rensningsjobbet; om gamla artiklar dyker upp igen efter att ha lästs, öka detta värde; negativa värden som -1 kommer att stänga av denna funktion.",
    "Delete unread articles automatically" : "Radera olästa artiklar automatiskt",
    "Enable this if you also want to delete unread articles." : "Aktivera detta om du också vill ta bort olästa artiklar.",
    "How many redirects the feed fetcher should follow." : "Hur många omdirigeringar flödet skall tillåtas följa.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximalt antal sekunder att vänta på att RSS/Atom-flödet läses in; om det tar längre tid avbryts uppdateringen.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Om det anges kommer URL:en för denna tjänst att användas för att visa flöden i avsnittet utforska flöden. Lämna detta fält tomt för att använda den inbyggda utforskningsfunktionen.",
    "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
    "Use next update time for feed updates" : "Använd nästa uppdateringstid för flödesuppdateringar",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Aktivera detta för att använda den beräknade nästa uppdateringstiden för flödesuppdateringar. Inaktivera för att uppdatera flöden baserat enbart på uppdateringsintervallet.",
    "Article list" : "Artikellista",
    "Article details" : "Artikeldetaljer",
    "No article selected" : "Ingen artikel har valts",
    "Please select an article from the list." : "Välj en artikel från listan.",
    "Show all articles" : "Visa alla artiklar",
    "Move feed" : "Flytta flöde",
    "Please select the new folder" : "Välj den nya mappen",
    "Move" : "Flytta",
    "User Name" : "Användarnamn",
    "Share" : "Dela",
    "Share with" : "Dela med",
    "Share with {num} users" : "Dela med {num} användare",
    "Rename Folder" : "Byt namn på mapp",
    "Are you sure you want to delete?" : "Är du säker på att du vill ta bort?",
    "Mark read" : "Markera som läst",
    "All articles" : "Alla artiklar",
    "Recently viewed" : "Senast visade",
    "Starred" : "Stjärnmärkt",
    "Has feeds with errors!" : "Har flöden med fel!",
    "Explore" : "Utforska",
    "Rename" : "Byt namn",
    "Delete" : "Ta bort",
    "Rename Feed" : "Döp om Feed",
    "Open Feed URL" : "Öppna flödes-URL",
    "Unpin from top" : "Ta bort från toppen",
    "Pin to top" : "Fäst i toppen",
    "Newest first" : "Nyaste först",
    "Oldest first" : "Äldst först",
    "Default order" : "Standardordning",
    "Enable full text" : "Aktivera fulltext",
    "Disable full text" : "Avaktivera fulltext",
    "Mark as unread on update" : "Markera som oläst vid uppdatering",
    "Keep read status on update" : "Behåll lässtatus vid uppdatering",
    "Sync disabled" : "Synk inaktiverad",
    "Sync enabled" : "Synk aktiverad",
    "Previous Item" : "Föregående objekt",
    "Next Item" : "Nästa objekt",
    "Share within Instance" : "Dela inom instans",
    "Toggle star article" : "Växla stjärnmärkning av artiklar",
    "Mark unread" : "Markera som oläst",
    "Close details" : "Stäng detaljer",
    "shared by" : "delad av",
    "by" : "av",
    "Play audio" : "Spela ljud",
    "Download audio" : "Hämta ljud",
    "Download video" : "Hämta video",
    "Refresh list" : "Uppdatera listan",
    "Open website" : "Öppna webbplats",
    "Keep article unread" : "Behåll artikel oläst",
    "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
    "Remove keep article unread" : "Ta bort behåll artikel oläst",
    "Default" : "Förvald",
    "Compact" : "Kompakt",
    "Screenreader" : "Skärmläsare",
    "Vertical" : "Vertikal",
    "Horizontal" : "Horisontell",
    "Off" : "Av",
    "Please select a valid OPML file" : "Välj en giltig OPML-fil",
    "File successfully uploaded" : "Filen har laddats upp",
    "Error uploading the opml file" : "Fel vid uppladdning av opml-filen",
    "Error connecting to the server" : "Fel vid anslutning till servern",
    "Error retrieving the opml file" : "Det gick inte att hämta opml-filen",
    "General" : "Allmänt",
    "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
    "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
    "Disable automatic refresh" : "Inaktivera automatisk uppdatering",
    "Appearance" : "Utseende",
    "Display mode" : "Visningsläge",
    "Split mode" : "Delat läge",
    "Import" : "Importera",
    "Export" : "Exportera",
    "Abonnements (OPML)" : "Prenumerationer (OPML)",
    "Importing feeds" : "Importerar flöden",
    "Please wait" : "Vänligen vänta",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Refresh" : "Uppdatera",
    "Jump to previous article" : "Hoppa till föregående artikel",
    "Jump to next article" : "Hoppa till nästa artikel",
    "Open article in new tab" : "Öppna artikeln i ny flik",
    "Show article details in compact view" : "Visa artikeldetaljer i kompakt vy",
    "Close article details in compact view" : "Stäng artikeldetaljer i kompakt vy",
    "Mark current articles feed/folder as read" : "Markera aktuellt artikelflöde/mapp som läst",
    "Resources" : "Resurser",
    "Last update" : "Senaste uppdatering",
    "Time when the feed was last downloaded" : "Tidpunkt då flödet senast laddades ned",
    "Next update" : "Nästa uppdatering",
    "Time when the next feed update will be done" : "Tidpunkt då nästa flödesuppdatering kommer att göras",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Endast om det är aktiverat i admininställningarna, annars används det vanliga uppdateringsintervallet",
    "Articles per update" : "Artiklar per uppdatering",
    "Maximum number of articles reached in a feed update" : "Maximalt antal artiklar nådda i en flödesuppdatering",
    "Error Count" : "Antal fel",
    "Number of errors that have occurred since the last successful feed update" : "Antal fel som har inträffat sedan den senaste framgångsrika flödesuppdateringen",
    "Title" : "Titel",
    "Folder" : "Mapp",
    "Not available" : "Inte tillgänglig",
    "All Articles" : "Alla artiklar",
    "No feeds found to add" : "Inga flöden hittades att lägga till",
    "Subscribe to" : "Prenumerera på",
    "Unread Articles" : "Olästa artiklar",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax- eller webcron-läge upptäckt! Dina flöden kommer inte uppdateras!",
    "How to set up the operating system cron" : "Hur man ställer in cron från operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installera och konfigurera en snabbare parallell uppdaterare som använder programmet Nyheter uppdatering API"
},
"nplurals=2; plural=(n != 1);");
